summaryrefslogtreecommitdiffstats
path: root/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java
diff options
context:
space:
mode:
Diffstat (limited to 'core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java')
-rw-r--r--core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java43
1 files changed, 38 insertions, 5 deletions
diff --git a/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java b/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java
index 13b8c0e2..7e1a7a22 100644
--- a/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java
+++ b/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/plugin/qemu/cmdln/CommandLineArgs.java
@@ -289,13 +289,43 @@ public class CommandLineArgs
}
/**
* Returns the argument of the command line option {@link CmdLnOption#VM_AUDIO0}.
*
* @return argument of the command line option {@link CmdLnOption#VM_AUDIO0}.
*/
- public String getVmModelSoundCard0()
+ public String getVmFsSrc0()
{
- return this.getArgument( CmdLnOption.VM_AUDIO0 );
+ return this.getArgument( CmdLnOption.VM_FSSRC0 );
+ }
+
+ /**
+ * Returns the argument of the command line option {@link CmdLnOption#VM_FSTGT0}.
+ *
+ * @return argument of the command line option {@link CmdLnOption#VM_FSTGT0}.
+ */
+ public String getVmFsTgt0()
+ {
+ return this.getArgument( CmdLnOption.VM_FSTGT0 );
+ }
+
+ /**
+ * Returns the argument of the command line option {@link CmdLnOption#VM_FSSRC1}.
+ *
+ * @return argument of the command line option {@link CmdLnOption#VM_FSSRC1}.
+ */
+ public String getVmFsSrc1()
+ {
+ return this.getArgument( CmdLnOption.VM_FSSRC1 );
+ }
+
+ /**
+ * Returns the argument of the command line option {@link CmdLnOption#VM_FSTGT1}.
+ *
+ * @return argument of the command line option {@link CmdLnOption#VM_FSTGT1}.
+ */
+ public String getVmFsTgt1()
+ {
+ return this.getArgument( CmdLnOption.VM_FSTGT1 );
}
/**
@@ -324,7 +354,10 @@ public class CommandLineArgs
VM_PARALLEL0( 'p', "vmparallel0", true, "Device for the first parallel port interface" ),
VM_SERIAL0 ( 'q', "vmserial0", true, "Device for the first serial port interface" ),
VM_MAC0 ( 'a', "vmmac0", true, "MAC address for the first network interface" ),
- VM_AUDIO0 ( 'x', "vmaudio0", true, "Hardware model for the first sound card" );
+ VM_FSSRC0 ( 't', "vmfssrc0", true, "Source directory for first file system passthrough (shared folder)" ),
+ VM_FSTGT0 ( 'u', "vmfstgt0", true, "Target directory for first file system passthrough (shared folder)" ),
+ VM_FSSRC1 ( 'v', "vmfssrc1", true, "Source directory for second file system passthrough (shared folder)" ),
+ VM_FSTGT1 ( 'w', "vmfstgt1", true, "Target directory for second file system passthrough (shared folder)" );
// @formatter:on
/**
@@ -289,13 +289,43 @@ public class CommandLineArgs
}
/**
- * Returns the argument of the command line option {@link CmdLnOption#VM_AUDIO0}.
+ * Returns the argument of the command line option {@link CmdLnOption#VM_FSSRC0}.
*
@@ -289,13 +289,43 @@ public class CommandLineArgs
*
- * @return argument of the command line option {@link CmdLnOption#VM_AUDIO0}.
+ * @return argument of the command line option {@link CmdLnOption#VM_FSSRC0}.
*/